#"Did the Founding of the Federal Reserve Affect the Vulnerability of the Interbank System to Contagion Risk?"
#JMCB ms. #16-292
#Mark Carlson and David C. Wheelock

#Perform calculations for panic withdrawals
#Create and export Figures 6 to 9 and Table 6

library(tidyverse)
library(plyr)
library(zoo)
library(data.table)

rm(list = ls())

#specify directory where folder is stored
dir <- ""
setwd(dir)

#read in function to insert gap between periods and create sequence to serve as x axis
source("programs/R functions/insert_gap.R")
#read in function to export figures
source("programs/R functions/ExportPlot.R")
#read in t test function
source("programs/R functions/ttest.R")
#read in function to transpose table
source("programs/R functions/transp.R")

#Section 1: Read and ready country bank data; calculaute panic withdrawals for country banks 
############################################################################################
#Read in country bank data
Country_data <- read.table("data/MS16-292EntirePeriod_states.txt", header = TRUE)
Country_data$mark_dt <- as.Date(Country_data$mark_dt, format="%m/%d/%Y")

#entries change from dollars to thousands of dollars in 1911; make units consistent
Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)] <- 
  Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)]*1000

#remove spaces from state names
Country_data$location <- str_replace_all(Country_data$location, " ", "")

#Keep only the 48 states
Country_data <- Country_data[Country_data$location != "Dakota" & 
                             Country_data$location != "Hawaii" & 
                             Country_data$location != "IndianTerritory",]

#replace NA's with 0's
Country_data[is.na(Country_data)] <- 0

#creates inddep_run; percent change in inddep from May 1893 to October 1893
Country_data <- data.table(Country_data)
Country_data[mark_dt=="1893-10-03" | mark_dt=="1893-05-04", 
             inddep_run := 100*(inddep/shift(inddep, n=1)-1), by=location]

#fills in value for all observations in a location
Country_data[, inddep_run := sum(inddep_run, na.rm=TRUE), by=location]

#creates sb_run; percent change in dt_state from May 1893 to October 1893
Country_data[mark_dt=="1893-10-03" | mark_dt=="1893-05-04", 
             sb_run := 100*(dt_state/shift(dt_state, n=1)-1), by=location]

#fills in value for all observations in a location
Country_data[, sb_run := sum(sb_run, na.rm=TRUE), by=location]

#converts back to regular data frame from data table
Country_data <- as.data.frame(Country_data)

#keeps dates in our sample period
Country_data <- Country_data[Country_data$mark_dt >= "1894-02-28",]
Country_data <- Country_data[Country_data$mark_dt <= "1914-09-12" | 
                             Country_data$mark_dt  > "1920-12-29",]
Country_data <- Country_data[Country_data$mark_dt <= "1928-06-30",]

#redefine inddep for dates >= 1921-02-21
Country_data[Country_data$mark_dt>="1921-02-21",]$inddep <- 
  with(Country_data[Country_data$mark_dt>="1921-02-21",], 
       Certified_checks_outstanding + Cashiers_checks_on_own_bank_outstanding +
       Dividend_checks_outstanding + Demand_deposits + Time_deposits)

#drain 
Country_data$drain <- 
  with(Country_data, 
      (inddep_run/100)*inddep + 
      (sb_run/100)*((dt_state + dt_savings)-df_state))

#agents 
Country_data$agents <- 
  with(Country_data, 
       df_redeem - dt_redeem + pmax(0, df_national - dt_national))

#on hand
Country_data$on_hand <- 
  with(Country_data, DuefromFed + Checks_on_other_banks_in_same_place + Outside_checks_other_cash_items +
                     cash_items + obank_bills + frac_curr + specie + vault.cash + legaltender + US_CD)

#amount drawn
Country_data$amount_drawn <- 
  with(Country_data, ifelse(drain<0, pmin(agents, pmax(0, abs(drain) - on_hand)), 0))

#reshape data
Country_data <- reshape(Country_data, timevar="location", idvar="mark_dt", direction="wide")

#sum of drain for country banks
Country_data$drain_country <- 
  with(Country_data, 
       drain.Alabama +       drain.Arizona +       drain.Arkansas +      
       drain.California +    drain.Colorado +      drain.Connecticut +   
       drain.Delaware +      drain.Florida +       drain.Georgia +   
       drain.Idaho +         drain.Illinois +      drain.Indiana +  
       drain.Iowa +          drain.Kansas +        drain.Kentucky +
       drain.Louisiana +     drain.Maine +         drain.Maryland +    
       drain.Massachusetts + drain.Michigan +      drain.Minnesota +     
       drain.Mississippi +   drain.Missouri +      drain.Montana +       
       drain.Nebraska +      drain.Nevada +        drain.NewHampshire + 
       drain.NewJersey +     drain.NewMexico +     drain.NewYork + 
       drain.NorthCarolina + drain.NorthDakota +   drain.Ohio +        
       drain.Oklahoma +      drain.Oregon +        drain.Pennsylvania +  
       drain.RhodeIsland +   drain.SouthCarolina + drain.SouthDakota + 
       drain.Tennessee +     drain.Texas +         drain.Utah +         
       drain.Vermont +       drain.Virginia +      drain.Washington +
       drain.WestVirginia +  drain.Wisconsin +     drain.Wyoming)

#sum of on hand for country banks
Country_data$on_hand_country <- 
  with(Country_data, 
       on_hand.Alabama +       on_hand.Arizona +       on_hand.Arkansas +  
       on_hand.California +    on_hand.Colorado +      on_hand.Connecticut +   
       on_hand.Delaware +      on_hand.Florida +       on_hand.Georgia + 
       on_hand.Idaho +         on_hand.Illinois +      on_hand.Indiana +      
       on_hand.Iowa +          on_hand.Kansas +        on_hand.Kentucky +
       on_hand.Louisiana +     on_hand.Maine +         on_hand.Maryland +    
       on_hand.Massachusetts + on_hand.Michigan +      on_hand.Minnesota +    
       on_hand.Mississippi +   on_hand.Missouri +      on_hand.Montana + 
       on_hand.Nebraska +      on_hand.Nevada +        on_hand.NewHampshire +
       on_hand.NewJersey +     on_hand.NewMexico +     on_hand.NewYork +
       on_hand.NorthCarolina + on_hand.NorthDakota +   on_hand.Ohio +
       on_hand.Oklahoma +      on_hand.Oregon +        on_hand.Pennsylvania +  
       on_hand.RhodeIsland +   on_hand.SouthCarolina + on_hand.SouthDakota + 
       on_hand.Tennessee +     on_hand.Texas +         on_hand.Utah +  
       on_hand.Vermont +       on_hand.Virginia +      on_hand.Washington +
       on_hand.WestVirginia +  on_hand.Wisconsin +     on_hand.Wyoming)

#sum of agents for country banks
Country_data$agents_country <- 
  with(Country_data, 
       agents.Alabama +       agents.Arizona +       agents.Arkansas +      
       agents.California +    agents.Colorado +      agents.Connecticut +  
       agents.Delaware +      agents.Florida +       agents.Georgia +       
       agents.Idaho +         agents.Illinois +      agents.Indiana +
       agents.Iowa +          agents.Kansas +        agents.Kentucky +
       agents.Louisiana +     agents.Maine +         agents.Maryland + 
       agents.Massachusetts + agents.Michigan +      agents.Minnesota +  
       agents.Mississippi +   agents.Missouri +      agents.Montana +       
       agents.Nebraska +      agents.Nevada +        agents.NewHampshire + 
       agents.NewJersey +     agents.NewMexico +     agents.NewYork +
       agents.NorthCarolina + agents.NorthDakota +   agents.Ohio +   
       agents.Oklahoma +      agents.Oregon +        agents.Pennsylvania + 
       agents.RhodeIsland +   agents.SouthCarolina + agents.SouthDakota +  
       agents.Tennessee +     agents.Texas +         agents.Utah + 
       agents.Vermont +       agents.Virginia +      agents.Washington +
       agents.WestVirginia +  agents.Wisconsin +     agents.Wyoming)

#sum of amount_drawn for country banks
Country_data$amount_drawn_country <- 
  with(Country_data, 
       amount_drawn.Alabama +       amount_drawn.Arizona +       amount_drawn.Arkansas + 
       amount_drawn.California +    amount_drawn.Colorado +      amount_drawn.Connecticut + 
       amount_drawn.Delaware +      amount_drawn.Florida +       amount_drawn.Georgia + 
       amount_drawn.Idaho +         amount_drawn.Illinois +      amount_drawn.Indiana + 
       amount_drawn.Iowa +          amount_drawn.Kansas +        amount_drawn.Kentucky +
       amount_drawn.Louisiana +     amount_drawn.Maine +         amount_drawn.Maryland + 
       amount_drawn.Massachusetts + amount_drawn.Michigan +      amount_drawn.Minnesota + 
       amount_drawn.Mississippi +   amount_drawn.Missouri +      amount_drawn.Montana + 
       amount_drawn.Nebraska +      amount_drawn.Nevada +        amount_drawn.NewHampshire + 
       amount_drawn.NewJersey +     amount_drawn.NewMexico +     amount_drawn.NewYork +
       amount_drawn.NorthCarolina + amount_drawn.NorthDakota +   amount_drawn.Ohio + 
       amount_drawn.Oklahoma +      amount_drawn.Oregon +        amount_drawn.Pennsylvania + 
       amount_drawn.RhodeIsland +   amount_drawn.SouthCarolina + amount_drawn.SouthDakota +
       amount_drawn.Tennessee +     amount_drawn.Texas +         amount_drawn.Utah +          
       amount_drawn.Vermont +       amount_drawn.Virginia +      amount_drawn.Washington +    
       amount_drawn.WestVirginia +  amount_drawn.Wisconsin +     amount_drawn.Wyoming)

#withdrawals relative to cash
Country_data$relative_to_cash_country <- 
  with(Country_data, 100*abs(drain_country)/(on_hand_country))

#withdrawals relative to cash and due from
Country_data$relative_to_cash_and_due_from_country <- 
  with(Country_data, 100*abs(drain_country)/(on_hand_country+agents_country))

#Section 2: 
#########################################################################################################################

#Read in reserve cities data
RCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE)
RCities_data$mark_dt <- as.Date(RCities_data$mark_dt, format="%m/%d/%Y")

#entries change from dollars to thousands of dollars in 1911
RCities_data[RCities_data$mark_dt >= "1911-01-01",3:ncol(RCities_data)] <- 
  RCities_data[RCities_data$mark_dt >= "1911-01-01",3:ncol(RCities_data)]*1000

#remove spaces from city names
RCities_data$location <- str_replace_all(RCities_data$location, " ", "")

#keep 18 reserve cities analyzed in paper
RCities_data <- RCities_data[RCities_data$location != "Indianapolis" & 
                             RCities_data$location != "Chicago" & 
                             RCities_data$location != "NewYork" & 
                             RCities_data$location != "StLouis",]

#replace NA's with 0's
RCities_data[is.na(RCities_data)] <- 0

#read in data for "all other reserve cities"
Other_RCities_data <- read.table("data/MS16-292AllOther_ReserveCities.txt", header = TRUE)
Other_RCities_data$mark_dt <- as.Date(Other_RCities_data$mark_dt)

#entries change from dollar to thousands of dollars in 1911
Other_RCities_data[Other_RCities_data$mark_dt >= "1911-01-01", 3:ncol(Other_RCities_data)] <- 
  Other_RCities_data[Other_RCities_data$mark_dt >= "1911-01-01", 3:ncol(Other_RCities_data)]*1000

#replace NA's with 0's
Other_RCities_data[is.na(Other_RCities_data)] <- 0

#keeps dates in our date range
Other_RCities_data <- Other_RCities_data[Other_RCities_data$mark_dt >= "1894-02-28",]
Other_RCities_data <- Other_RCities_data[Other_RCities_data$mark_dt <= "1914-09-12" |
                                         Other_RCities_data$mark_dt >  "1920-12-29",]
Other_RCities_data <- Other_RCities_data[Other_RCities_data$mark_dt <= "1928-06-30",]

#append all other cities data to reserve cities data
RCities_data <- rbind(RCities_data, Other_RCities_data)

#Convert to data.table
RCities_data <- data.table(RCities_data)

#creates inddep_run and sb_run; percent change in inddep and dt_state from May 1893 to October 1893
RCities_data[mark_dt=="1893-10-03" | mark_dt=="1893-05-04", 
             inddep_run := 100*(inddep/shift(inddep, n=1)-1), by=location]

RCities_data[, inddep_run := sum(inddep_run, na.rm=TRUE), by=location]

RCities_data[mark_dt=="1893-10-03" | mark_dt=="1893-05-04", 
             sb_run := 100*(dt_state/shift(dt_state, n=1)-1), by=location]

RCities_data[, sb_run := sum(sb_run, na.rm=TRUE), by=location]

#subsets on date
RCities_data <- RCities_data[RCities_data$mark_dt >= "1894-02-28",]
RCities_data <- RCities_data[RCities_data$mark_dt <= "1914-09-12" | 
                             RCities_data$mark_dt >  "1920-12-29",]
RCities_data <- RCities_data[RCities_data$mark_dt <= "1928-06-30",]

#replaces inddep_run for all other reserve cities with median of inddep_run for 18 RC's in our data
RCities_data[mark_dt=="1894-02-28" & location!="AllOther", inddep_run_median:= median(inddep_run)]
RCities_data$inddep_run_median <- na.locf(RCities_data$inddep_run_median) 
RCities_data[RCities_data$location=="AllOther",]$inddep_run <- 
  RCities_data[RCities_data$location=="AllOther",]$inddep_run_median

#replaces sb_run for all othe reserve cities with median of inddep_run for 18 RC's in our data
RCities_data[mark_dt=="1894-02-28" & location!="AllOther", sb_run_median:= median(sb_run)]
RCities_data$sb_run_median <- na.locf(RCities_data$sb_run_median) 
RCities_data[RCities_data$location=="AllOther",]$sb_run <- 
  RCities_data[RCities_data$location=="AllOther",]$sb_run_median

#removes inddep_run_median and sb_run_median from our data
RCities_data[, c("inddep_run_median", "sb_run_median") := NULL]

#converts back to regular data frame from data table
RCities_data <- as.data.frame(RCities_data)

#creates and reshapes separate data frame to calculate sum of dt_national for all reserve cities
RCities_dt_national <- RCities_data[,c("mark_dt", "location", "dt_national")]
RCities_dt_national <- reshape(RCities_dt_national, timevar="location", idvar="mark_dt", direction="wide")

RCities_dt_national$dt_national_reserve_city <- 
  with(RCities_dt_national, 
       dt_national.Albany +       dt_national.Baltimore +  dt_national.Boston +
       dt_national.Cincinnati +   dt_national.Cleveland +  dt_national.Detroit +
       dt_national.KansasCityM +  dt_national.Louisville + dt_national.Milwaukee +
       dt_national.Minneapolis +  dt_national.NewOrleans + dt_national.Omaha +
       dt_national.Philadelphia + dt_national.Pittsburgh + dt_national.SanFrancisco +
       dt_national.StJoseph +     dt_national.StPaul +     dt_national.Washington +
       dt_national.AllOther)

#merge in dt_national_reserve_city
RCities_data <- merge(RCities_data, RCities_dt_national[,c("mark_dt", "dt_national_reserve_city")], by = "mark_dt")
#merge amount_drawn_country with reserve city data
RCities_data <- merge(RCities_data, Country_data[,c("mark_dt", "amount_drawn_country")], by="mark_dt")
#sort data on location and date
RCities_data <- RCities_data[order(RCities_data$location, RCities_data$mark_dt),]

#redefines inddep for dates >= 1921-02-21
RCities_data[RCities_data$mark_dt>="1921-02-21",]$inddep <- 
  with(RCities_data[RCities_data$mark_dt>="1921-02-21",], 
       Certified_checks_outstanding + Cashiers_checks_on_own_bank_outstanding +
       Dividend_checks_outstanding + Demand_deposits + Time_deposits)

#drawdown
RCities_data$drawdown <- 
  with(RCities_data, 
       0.67*(dt_national/dt_national_reserve_city)*amount_drawn_country)

#drain
RCities_data$drain <- 
  with(RCities_data, 
       (inddep_run/100)*inddep + (sb_run/100)*(dt_state+ dt_savings - df_state)-drawdown)

#on_hand
RCities_data$on_hand <- 
  with(RCities_data, 
       DuefromFed + Checks_on_other_banks_in_same_place + Outside_checks_other_cash_items +
       cash_items + obank_bills + frac_curr + specie + legaltender + vault.cash + US_CD)

#agents
RCities_data$agents <- 0
RCities_data[RCities_data$mark_dt<="1914-09-12",]$agents <- 
  with(RCities_data[RCities_data$mark_dt<="1914-09-12",], 
       df_redeem - dt_redeem)
RCities_data[RCities_data$mark_dt>="1921-02-21",]$agents <- 
  with(RCities_data[RCities_data$mark_dt>="1921-02-21",], 
       0.65*df_national)

#amount_drawn
RCities_data$amount_drawn <- 
  with(RCities_data, 
       ifelse(drain<0, pmin(agents, pmax(0, abs(drain) - on_hand)), 0))

#create separate data frame used to calculate number of banks that exhaust liquidity 
RCities_exhaust_liquidity <- RCities_data

#reshape reserve city data
RCities_data <- reshape(RCities_data, timevar="location", idvar="mark_dt", direction="wide")

#sum of drawdown across all reserve cities
RCities_data$drawdown_reserve_city <- 
  with(RCities_data, 
       drawdown.Albany +        drawdown.Baltimore +  drawdown.Boston +
       drawdown.Cincinnati +    drawdown.Cleveland +  drawdown.Detroit +
       drawdown.KansasCityM +   drawdown.Louisville + drawdown.Milwaukee +
       drawdown.Minneapolis +   drawdown.NewOrleans + drawdown.Omaha +
       drawdown.Philadelphia +  drawdown.Pittsburgh + drawdown.SanFrancisco +
       drawdown.StJoseph +      drawdown.StPaul +     drawdown.Washington +
       drawdown.AllOther)

#sum of drain across all reserve cities
RCities_data$drain_reserve_city <- 
  with(RCities_data, 
       drain.Albany +       drain.Baltimore +  drain.Boston +
       drain.Cincinnati +   drain.Cleveland +  drain.Detroit +
       drain.KansasCityM +  drain.Louisville + drain.Milwaukee +
       drain.Minneapolis +  drain.NewOrleans + drain.Omaha +
       drain.Philadelphia + drain.Pittsburgh + drain.SanFrancisco +
       drain.StJoseph +     drain.StPaul +     drain.Washington +
       drain.AllOther)

#sum of on_hand for all reserve cities
RCities_data$on_hand_reserve_city <- 
  with(RCities_data, 
       on_hand.Albany +       on_hand.Baltimore +  on_hand.Boston +
       on_hand.Cincinnati +   on_hand.Cleveland +  on_hand.Detroit +
       on_hand.KansasCityM +  on_hand.Louisville + on_hand.Milwaukee +
       on_hand.Minneapolis +  on_hand.NewOrleans + on_hand.Omaha +
       on_hand.Philadelphia + on_hand.Pittsburgh + on_hand.SanFrancisco +
       on_hand.StJoseph +     on_hand.StPaul +     on_hand.Washington +
       on_hand.AllOther)

#sum of agents for all reserve cities
RCities_data$agents_reserve_city <- 
  with(RCities_data, 
       agents.Albany +       agents.Baltimore +  agents.Boston +
       agents.Cincinnati +   agents.Cleveland +  agents.Detroit +
       agents.KansasCityM +  agents.Louisville + agents.Milwaukee +
       agents.Minneapolis +  agents.NewOrleans + agents.Omaha +
       agents.Philadelphia + agents.Pittsburgh + agents.SanFrancisco +
       agents.StJoseph +     agents.StPaul +     agents.Washington +
       agents.AllOther)

#amount_drawn_reserve_city
RCities_data$amount_drawn_reserve_city <- 
  with(RCities_data, 
       amount_drawn.Albany +       amount_drawn.Baltimore +  amount_drawn.Boston +
       amount_drawn.Cincinnati +   amount_drawn.Cleveland +  amount_drawn.Detroit +
       amount_drawn.KansasCityM +  amount_drawn.Louisville + amount_drawn.Milwaukee +
       amount_drawn.Minneapolis +  amount_drawn.NewOrleans + amount_drawn.Omaha +
       amount_drawn.Philadelphia + amount_drawn.Pittsburgh + amount_drawn.SanFrancisco +
       amount_drawn.StJoseph +     amount_drawn.StPaul +     amount_drawn.Washington +
       amount_drawn.AllOther)

#drain relative to cash
RCities_data$relative_to_cash_reserve_city <- 
  with(RCities_data, 
       100*(abs(drain_reserve_city)/on_hand_reserve_city))

#drain relative to cash and due from
RCities_data$relative_to_cash_and_due_from_reserve_city <- 
  with(RCities_data, 
       100*(abs(drain_reserve_city)/(on_hand_reserve_city+agents_reserve_city)))

#Section 3: 
####################################################################################################################### 

#Read in data for Central Reserve Cities
CRCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE)
CRCities_data$mark_dt <- as.Date(CRCities_data$mark_dt, format="%m/%d/%Y")

#entries go from dollars to thousands of dollars in 1911
CRCities_data[CRCities_data$mark_dt >= "1911-01-01",3:ncol(CRCities_data)] <- 
  CRCities_data[CRCities_data$mark_dt >= "1911-01-01",3:ncol(CRCities_data)]*1000

#remove spaces from names of cities
CRCities_data$location <- str_replace_all(CRCities_data$location, " ", "")
CRCities_data <- CRCities_data[CRCities_data$location == "Chicago" | 
                               CRCities_data$location == "NewYork" | 
                               CRCities_data$location == "StLouis",]

#replace NA's with 0's
CRCities_data[is.na(CRCities_data)] <- 0

#convert to data.table
CRCities_data <- data.table(CRCities_data)

#creates inddep_run and sb_run; percent change in inddep and dt_state from May 1893 to October 1893
CRCities_data[mark_dt=="1893-10-03" | mark_dt=="1893-05-04", 
              inddep_run := 100*(inddep/shift(inddep, n=1)-1), by=location]

CRCities_data[, inddep_run := sum(inddep_run, na.rm=TRUE), by=location]

CRCities_data[mark_dt=="1893-10-03" | mark_dt=="1893-05-04", 
              sb_run := 100*(dt_state/shift(dt_state, n=1)-1), by=location]

CRCities_data[, sb_run := sum(sb_run, na.rm=TRUE), by=location]

#converts back to regular data frame from data table
CRCities_data <- as.data.frame(CRCities_data)

#creates separate data frame to calculate sum of dt_national for central reserve cities
CRCities_dt_national <- CRCities_data[,c("mark_dt", "location", "dt_national", "df_national")]

CRCities_dt_national <- reshape(CRCities_dt_national, timevar="location", idvar="mark_dt", direction="wide")

CRCities_dt_national$dt_national_central_reserve_city <- 
  with(CRCities_dt_national, 
       dt_national.Chicago + dt_national.NewYork + dt_national.StLouis - 
       df_national.Chicago - df_national.NewYork - df_national.StLouis)

#merge CRCities_dt_national with rest of data for central reserve cities
CRCities_data <- 
  merge(CRCities_data, 
        CRCities_dt_national[,c("mark_dt", "dt_national_central_reserve_city")], by = "mark_dt")

#merge amount_drawn_country with central reserve city data
CRCities_data <- 
  merge(CRCities_data, 
        Country_data[,c("mark_dt", "amount_drawn_country")], by="mark_dt")

#merge amount_drawn_reserve_city with central reserve city data
CRCities_data <- 
  merge(CRCities_data, 
        RCities_data[,c("mark_dt", "amount_drawn_reserve_city")], by="mark_dt")

#sort data on location and date
CRCities_data <- 
  CRCities_data[order(CRCities_data$location, CRCities_data$mark_dt),]

#drawdown
CRCities_data$drawdown <- 
  with(CRCities_data, 
       0.33*((dt_national-df_national)/dt_national_central_reserve_city)*amount_drawn_country+
            ((dt_national-df_national)/dt_national_central_reserve_city)*amount_drawn_reserve_city)

#redefine inddep for dates >= 1921-02-21
CRCities_data[CRCities_data$mark_dt>="1921-02-21",]$inddep <- 
  with(CRCities_data[CRCities_data$mark_dt>="1921-02-21",], 
       Certified_checks_outstanding + Cashiers_checks_on_own_bank_outstanding +
       Dividend_checks_outstanding + Demand_deposits + Time_deposits)

#drain
CRCities_data$drain <- 
  with(CRCities_data, 
       (inddep_run/100)*inddep + (sb_run/100)*(dt_state-df_state)-drawdown)

#on_hand 
CRCities_data$on_hand <- 
  with(CRCities_data, 
       DuefromFed + Checks_on_other_banks_in_same_place + Outside_checks_other_cash_items +
       cash_items + obank_bills + frac_curr + specie + legaltender + vault.cash + US_CD)

#indicator: on_hand + drain <0 then 1
CRCities_data$exhaust_cash <- 
  with(CRCities_data, 
       ifelse(on_hand + drain <0, 1, 0))

#reshape central reserve city data
CRCities_data <- reshape(CRCities_data, timevar="location", idvar="mark_dt", direction="wide")

#sum of drawdown for central reserve cities
CRCities_data$drawdown_central_reserve_city <- 
  with(CRCities_data, 
       drawdown.Chicago + drawdown.NewYork + drawdown.StLouis)

#sum of drain for central reserve cities
CRCities_data$drain_central_reserve_city <- 
  with(CRCities_data, 
       drain.Chicago + drain.NewYork + drain.StLouis)

#sum of on hand for central reserve cities
CRCities_data$on_hand_central_reserve_city <- 
  with(CRCities_data, 
       on_hand.Chicago + on_hand.NewYork + on_hand.StLouis)

#drain relative to cash for central reserve cities
CRCities_data$relative_to_cash_central_reserve_city <- 
  with(CRCities_data, 
       100*(abs(drain_central_reserve_city))/on_hand_central_reserve_city)

#tallies how many central reserve cities would have exhausted cash on any given date
CRCities_data$exhaust_cash_central_reserve_city <- 
  with(CRCities_data, 
       exhaust_cash.Chicago + exhaust_cash.NewYork + exhaust_cash.StLouis)

#Section 4: Adjust for suspension of CRC banks and calculate number of cities exhausting liquidity
##################################################################################################
#read in reserve city data
RCities_spillback <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE)
RCities_spillback$mark_dt <- as.Date(RCities_spillback$mark_dt, format="%m/%d/%Y")

#entries changed from dollars to thousands of dollars in 1911
RCities_spillback[RCities_spillback$mark_dt >= "1911-01-01",3:ncol(RCities_spillback)] <- 
  RCities_spillback[RCities_spillback$mark_dt >= "1911-01-01",3:ncol(RCities_spillback)]*1000

#remove spaces from city names
RCities_spillback$location <- str_replace_all(RCities_spillback$location, " ", "")

#Keep 18 cities used in analysis
RCities_spillback <- 
  RCities_spillback[RCities_spillback$location != "Indianapolis" & 
                    RCities_spillback$location != "Chicago" & 
                    RCities_spillback$location != "NewYork" & 
                    RCities_spillback$location != "StLouis",]

#replace NA's with 0's
RCities_spillback[is.na(RCities_spillback)] <- 0

#combine reserve city data with data for all other reserve cities
RCities_spillback <- rbind(RCities_spillback, Other_RCities_data)

#agents
RCities_spillback$agents <- 0

RCities_spillback[RCities_spillback$mark_dt<="1914-09-12",]$agents <- 
  with(RCities_spillback[RCities_spillback$mark_dt<="1914-09-12",], 
       df_redeem - dt_redeem)

RCities_spillback[RCities_spillback$mark_dt>="1921-02-21",]$agents <- 
  with(RCities_spillback[RCities_spillback$mark_dt>="1921-02-21",], 
       0.65*df_national)

#merge reserve city data with drain_central_reserve_city and on_hand_central_reserve_city
RCities_spillback <- merge(RCities_spillback, 
                           CRCities_data[,c("mark_dt", 
                                            "drain_central_reserve_city", 
                                            "on_hand_central_reserve_city")], 
                                            by="mark_dt")

#sort on location and date
RCities_spillback <- RCities_spillback[order(RCities_spillback$location, 
                                             RCities_spillback$mark_dt),]

#spillback
RCities_spillback$spillback <- 
  with(RCities_spillback, 
       ifelse((100*abs(drain_central_reserve_city)/on_hand_central_reserve_city)>100, 
               100/(100*(abs(drain_central_reserve_city)/on_hand_central_reserve_city)), 1))

#spill_agents
RCities_spillback$spill_agents <- with(RCities_spillback, agents*spillback)

#merge reserve_city_exhaust_liquidity with reserve_city spillback's location and spill_agents
RCities_exhaust_liquidity <- 
  merge(RCities_exhaust_liquidity, 
        RCities_spillback[,c("mark_dt", "location","spill_agents")], by=c("mark_dt", "location"))

#sort on location and date
RCities_exhaust_liquidity <- 
  RCities_exhaust_liquidity[order(RCities_exhaust_liquidity$location, 
        RCities_exhaust_liquidity$mark_dt),]

#reshape RCities_spillback
RCities_spillback <- reshape(RCities_spillback, timevar="location", idvar="mark_dt", direction="wide")

#spill_agent_avail
RCities_spillback$spill_agent_avail <- 
  with(RCities_spillback, 
       spill_agents.Albany +       spill_agents.Baltimore +  spill_agents.Boston +
       spill_agents.Cincinnati +   spill_agents.Cleveland +  spill_agents.Detroit +
       spill_agents.KansasCityM +  spill_agents.Louisville + spill_agents.Milwaukee +
       spill_agents.Minneapolis +  spill_agents.NewOrleans + spill_agents.Omaha +
       spill_agents.Philadelphia + spill_agents.Pittsburgh + spill_agents.SanFrancisco +
       spill_agents.StJoseph +     spill_agents.StPaul +     spill_agents.Washington +
       spill_agents.AllOther)

#merge spill_agent_avail with reserve city data
RCities_data <- merge(RCities_data, RCities_spillback[,c("mark_dt", "spill_agent_avail")], by="mark_dt")

#drain for reserve cities adjusted for CRC suspension
RCities_data$adjusted_for_CRC_suspension <- 
  with(RCities_data, 100*(abs(drain_reserve_city))/(spill_agent_avail + on_hand_reserve_city))

#Indicator; if on_hand+agents+drain <0 then 1
RCities_exhaust_liquidity$exhaust_liquidity <- 
  with(RCities_exhaust_liquidity, ifelse(on_hand + agents + drain <0, 1, 0))

#exhaust_liquidity_adjusted_CRC; indicator 
RCities_exhaust_liquidity$exhaust_liquidity_adjusted_CRC <- 
  with(RCities_exhaust_liquidity, ifelse(on_hand + spill_agents + drain <0, 1, 0))

#adjusted for CRC_suspension; marginal exhaust liquidity by CRC suspension
RCities_exhaust_liquidity$adjusted_for_CRC_suspension <- 
  with(RCities_exhaust_liquidity, exhaust_liquidity_adjusted_CRC - exhaust_liquidity)

#reshape reserve_city_exhaust_liquidity
RCities_exhaust_liquidity<- reshape(RCities_exhaust_liquidity, timevar="location", idvar="mark_dt", direction="wide")

# number of reserve cities would have exhausted liquidity 
RCities_exhaust_liquidity$exhaust_liquidity_reserve_city <- 
  with(RCities_exhaust_liquidity, 
       exhaust_liquidity.Albany +       exhaust_liquidity.Baltimore +  exhaust_liquidity.Boston +
       exhaust_liquidity.Cincinnati +   exhaust_liquidity.Cleveland +  exhaust_liquidity.Detroit +
       exhaust_liquidity.KansasCityM +  exhaust_liquidity.Louisville + exhaust_liquidity.Milwaukee +
       exhaust_liquidity.Minneapolis +  exhaust_liquidity.NewOrleans + exhaust_liquidity.Omaha +
       exhaust_liquidity.Philadelphia + exhaust_liquidity.Pittsburgh + exhaust_liquidity.SanFrancisco +
       exhaust_liquidity.StJoseph +     exhaust_liquidity.StPaul +     exhaust_liquidity.Washington +
       exhaust_liquidity.AllOther)

# number of cities would have exhausted liquidity due to CRC_suspension
RCities_exhaust_liquidity$adjusted_for_CRC_suspension_reserve_city <- 
  with(RCities_exhaust_liquidity, 
       adjusted_for_CRC_suspension.Albany +       adjusted_for_CRC_suspension.Baltimore +  
       adjusted_for_CRC_suspension.Boston +       adjusted_for_CRC_suspension.Cincinnati + 
       adjusted_for_CRC_suspension.Cleveland +    adjusted_for_CRC_suspension.Detroit +
       adjusted_for_CRC_suspension.KansasCityM +  adjusted_for_CRC_suspension.Louisville + 
       adjusted_for_CRC_suspension.Milwaukee +    adjusted_for_CRC_suspension.Minneapolis +  
       adjusted_for_CRC_suspension.NewOrleans +   adjusted_for_CRC_suspension.Omaha +
       adjusted_for_CRC_suspension.Philadelphia + adjusted_for_CRC_suspension.Pittsburgh + 
       adjusted_for_CRC_suspension.SanFrancisco + adjusted_for_CRC_suspension.StJoseph +     
       adjusted_for_CRC_suspension.StPaul +       adjusted_for_CRC_suspension.Washington +
       adjusted_for_CRC_suspension.AllOther)

#Section 5: Create and export Figure 6 through 9
#########################################################################################################

#Keeps and merges variables used in Figures 6 through 9 into single data frame
Figure6_9 <- RCities_data[,c("mark_dt", "relative_to_cash_reserve_city", 
                             "relative_to_cash_and_due_from_reserve_city", 
                             "adjusted_for_CRC_suspension")]

Figure6_9 <- merge(Figure6_9, RCities_exhaust_liquidity[,
                              c("mark_dt", "exhaust_liquidity_reserve_city", 
                                "adjusted_for_CRC_suspension_reserve_city")], 
                   by=c("mark_dt"))

Figure6_9 <- merge(Figure6_9, CRCities_data[,
                              c("mark_dt", "relative_to_cash_central_reserve_city", 
                                "exhaust_cash_central_reserve_city")], 
                   by=c("mark_dt"))

#call function used to insert gap and create sequence used as x axis in figures
Figure6_9 <- insert_gap(Figure6_9)

#specify axis breaks
xbreaks <- which(as.character(Figure6_9$mark_dt) %in% 
                   c("1894-05-04", "1895-05-07", "1896-05-07",
                     "1897-05-14", "1898-05-05", "1899-06-30",
                     "1900-06-29", "1901-07-15", "1902-07-16", 
                     "1903-06-09", "1904-06-09", "1905-05-29",
                     "1906-06-18", "1907-05-20", "1908-07-15",
                     "1909-06-23", "1910-06-30", "1911-06-07",
                     "1912-06-14", "1913-06-04", "1914-06-30",
                     "1921-06-30", "1922-06-30", "1923-06-30",
                     "1924-06-30", "1925-06-30", "1926-06-30",
                     "1927-06-30", "1928-06-30"))

#specify axis labels
xlabels=c("1894", "1895", "1896",
          "1897", "1898", "1899",
          "1900", "1901", "1902", 
          "1903", "1904", "1905",
          "1906", "1907", "1908",
          "1909", "1910", "1911",
          "1912", "1913", "1914",
          "1921", "1922", "1923",
          "1924", "1925", "1926",
          "1927", "1928")

#reshape data for use in ggplot
Figure6_9 <- melt(Figure6_9, id.vars = c("mark_dt", "xseq"))

#reorder factor level to get required reserve ratio on bottom of the plot
Figure6_9$variable <- 
  factor(Figure6_9$variable,levels=c("relative_to_cash_reserve_city",
                                     "relative_to_cash_and_due_from_reserve_city",
                                     "adjusted_for_CRC_suspension",
                                     "adjusted_for_CRC_suspension_reserve_city",
                                     "exhaust_liquidity_reserve_city",
                                     "relative_to_cash_central_reserve_city",
                                     "exhaust_cash_central_reserve_city"))

#create Figure 6
Figure6 <- 
  #variables plotted in Figure 6
  ggplot(data=Figure6_9[Figure6_9$variable=="relative_to_cash_reserve_city" |
                          Figure6_9$variable=="relative_to_cash_and_due_from_reserve_city" |
                          Figure6_9$variable=="adjusted_for_CRC_suspension",],
         #x axis is sequence, y axis value of variable, and different linetype for each variable
         aes(x=xseq,y=value,linetype=variable)) +
  #line plot
  geom_line() +
  #specify x axis breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels) +
  coord_cartesian(ylim=c(0, 250))+
  #specify y axis breaks
  scale_y_continuous(expand=c(0,0), breaks=c(0, 50, 100, 150, 200, 250)) +
  #line type/legend
  scale_linetype_manual(labels=c("Relative to cash", "Relative to cash and due from", "Adjusted for CRC suspension"), 
                        values=c("solid", "dashed", "dotted"))+
  #theme/design
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11),
        legend.position = c(.18, .9),
        legend.title = element_blank())+
  #insert vertical dashed line to separate periods
  geom_vline(xintercept=107, linetype="dashed")

#Export Figure 6
ExportPlot(Figure6, "output/MS16-292Figure 6", width=6.45, height=3.26)

#Create Figure 7
Figure7 <-
  ggplot(data=Figure6_9[Figure6_9$variable=="exhaust_liquidity_reserve_city" |
                          Figure6_9$variable=="adjusted_for_CRC_suspension_reserve_city",],
         aes(x=xseq ,y=value, fill=variable)) +
  #bar chart
  geom_bar(stat = "identity", width=.6) +
  #format axis labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels, expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0), breaks=c(0, 2, 4, 6, 8, 10, 12, 14, 16, 18)) +
  coord_cartesian(ylim=c(0,18))+
  #theme
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11),
        legend.position = c(.2, .9),
        legend.title = element_blank())+
  guides(fill = guide_legend(reverse = TRUE)) +
  #insert dashed vertical line
  geom_vline(xintercept=107, linetype="dashed")+
  #specify colors and legend descriptions
  scale_fill_manual(values=c("dark gray", "black"), labels = c("Adjusted for CRC suspension", "Exhaust Liquidity"))

#Export Figure 7
ExportPlot(Figure7, "output/MS16-292Figure 7", width=6.45, height=3.31)

#Create Figure 8
Figure8 <-
  #x axis sequence, y axis PC1 of dt_national_CRC
  ggplot(data=Figure6_9[Figure6_9$variable=="relative_to_cash_central_reserve_city",], 
         aes(x=xseq,y=value)) +
  #line plot
  geom_line() +
  scale_y_continuous(expand=c(0,0), breaks=c(0, 50, 100, 150, 200, 250)) +
  coord_cartesian(ylim=c(0,250))+
  #x axis breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels) +
  #theme
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11))+
  #insert vertical line at gap
  geom_vline(xintercept=107, linetype="dashed")

#Export Figure 8
ExportPlot(Figure8, "output/MS16-292Figure 8", width=6.45, height=3.56)

#Create Figure 9
Figure9 <-
  ggplot(data=Figure6_9[Figure6_9$variable=="exhaust_cash_central_reserve_city",],
         aes(x=xseq, y=value)) +
  #bar chart
  geom_bar(stat = "identity", width=.6, fill="black") +
  coord_cartesian(ylim=c(0, 3))+
  #specify breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels, expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0), breaks=c(0, 1, 2, 3)) +
  #classic theme; format axis labels
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11))+
  #add vertical dashed line to signify gap
  geom_vline(xintercept=107, linetype="dashed")

#Export Figure 9
ExportPlot(Figure9, "output/MS16-292Figure 9", width=6.27, height=3.56)

#Section 6: Create and export Table 6
#########################################################################################################

#Merge variables needed for Table 6 into single data frame
Table6 <- Country_data[,c("mark_dt",
                          "relative_to_cash_country",
                          "relative_to_cash_and_due_from_country")]

Table6 <- merge(Table6, 
                RCities_data[,c("mark_dt",
                                "relative_to_cash_reserve_city",
                                "relative_to_cash_and_due_from_reserve_city")])

Table6 <- merge(Table6, 
                CRCities_data[,c("mark_dt",
                                 "relative_to_cash_central_reserve_city")])

#Create period variable to group by in table
Table6$period <- "1894-1914"
Table6[Table6$mark_dt>="1921-02-21", "period"] <- "1921-1928"

#Perform t tests
relative_to_cash_country_t <- 
  ttest(Table6[Table6$period=="1921-1928","relative_to_cash_country"],
        Table6[Table6$period=="1894-1914","relative_to_cash_country"])

relative_to_cash_and_due_from_country_t <- 
  ttest(Table6[Table6$period=="1921-1928","relative_to_cash_and_due_from_country"],
        Table6[Table6$period=="1894-1914","relative_to_cash_and_due_from_country"])

relative_to_cash_reserve_city_t <- 
  ttest(Table6[Table6$period=="1921-1928","relative_to_cash_reserve_city"],
        Table6[Table6$period=="1894-1914","relative_to_cash_reserve_city"])

relative_to_cash_and_due_from_reserve_city_t <- 
  ttest(Table6[Table6$period=="1921-1928","relative_to_cash_and_due_from_reserve_city"],
        Table6[Table6$period=="1894-1914","relative_to_cash_and_due_from_reserve_city"])

relative_to_cash_central_reserve_city_t <- 
  ttest(Table6[Table6$period=="1921-1928","relative_to_cash_central_reserve_city"],
        Table6[Table6$period=="1894-1914","relative_to_cash_central_reserve_city"])

#Convert to data.table
Table6 <- as.data.table(Table6)

#Calculate means and standard deviations of variables and collapse on period
Table6 <- 
  Table6[, 
      .('Country banks: relative to cash on hand (Mean)'=mean(relative_to_cash_country),
        'Country banks: relative to cash on hand (SD)'=sd(relative_to_cash_country),
        'Country banks: relative to cash on hand and deposits due from banks (Mean)'=mean(relative_to_cash_and_due_from_country),
        'Country banks: relative to cash on hand and deposits due from banks (SD)'=sd(relative_to_cash_and_due_from_country),
        'Reserve city banks: relative to cash on hand (Mean)'=mean(relative_to_cash_reserve_city),
        'Reserve city banks: relative to cash on hand (SD)'=sd(relative_to_cash_reserve_city),
        'Reserve city banks: relative to cash on hand and deposits due from banks (Mean)'=mean(relative_to_cash_and_due_from_reserve_city),
        'Reserve city banks: relative to cash on hand and deposits due from banks (SD)'=sd(relative_to_cash_and_due_from_reserve_city),
        'Central reserve city banks: relative to cash on hand (Mean)'=mean(relative_to_cash_central_reserve_city),
        'Central reserve city banks: relative to cash on hand (SD)'=sd(relative_to_cash_central_reserve_city)), 
      by=period]

#transpose Table 6
Table6 <- transp(Table6)

#Convert Table 6 back to data.frame
Table6 <- as.data.frame(Table6)

#Plug t statistics into Table 6
Table6$'T-statistic for differences' <- NA

Table6['Country banks: relative to cash on hand (Mean)', 
       "T-statistic for for differences"] <- relative_to_cash_country_t

Table6['Country banks: relative to cash on hand and deposits due from banks (Mean)', 
       "T-statistic for for differences"] <- relative_to_cash_and_due_from_country_t

Table6['Reserve city banks: relative to cash on hand (Mean)', 
       "T-statistic for for differences"] <- relative_to_cash_reserve_city_t

Table6['Reserve city banks: relative to cash on hand and deposits due from banks (Mean)', 
       "T-statistic for for differences"] <- relative_to_cash_and_due_from_reserve_city_t

Table6['Central reserve city banks: relative to cash on hand (Mean)', 
       "T-statistic for for differences"] <- relative_to_cash_central_reserve_city_t

#Export Table 6 to .csv
write.csv(Table6, file = "output/MS16-292Table 6.csv")