*===============================================================================
*Last edited 4/25/2018.
*Project: Did the Founding of the Federal Reserve Affect the Vulnerability of 
*         the Interbank System to Contagion Risk?
*Economists: David Wheelock and Mark Carlson
*Purpose: Run regression to analyze seasonal patterns in Federal Reserve credit.
*         Create and export Table 2.
*
*===============================================================================
clear all
set more off 

*specify directory where folder is stored
cd ""
*read in data and format Date variable
import delimited  "data\MS16-292Seasonal_patterns.txt", case(preserve)
gen Date2 = monthly(Date, "ym")
format Date2 %tm
drop Date
rename Date2 Date

*specify variable labels
label variable month_dummy1 "January"
label variable month_dummy2 "February"
label variable month_dummy3 "March"
label variable month_dummy4 "April"
label variable month_dummy5 "May"
label variable month_dummy6 "June"
label variable month_dummy7 "July"
label variable month_dummy8 "August"
label variable month_dummy9 "Setpember"
label variable month_dummy10 "October"
label variable month_dummy11 "November"
label variable month_dummy12 "December"
label variable IP_diff "Industrial Production"
label variable last_time_trnd "Time trend"

*===============================================================================
*       This section of code estimates a model of demand for 
*		discounts/acceptances with a dummy variable for each month of the 
*		year, a variable equal to the difference in the IP series at time 
*		t and January 1915, and a time trend variable. More precisely:
*	
*	Sample: January 1922 - August 1931
*	MODEL:
*		Demand_t = a + b1*January + b2*February + ... + b12*December + 
*		           c*IP_Difference + d*Time_Trend + error
*===============================================================================
noisily reg sum_discounts_acceptances_perMil month_dummy1-month_dummy12 IP_diff ///
		last_time_trnd if Date >= tm(1922m1) & Date <= tm(1931m8) ///
		& Dist_ID == 0, nocons

*store estimates
estimates store sub_diff_IP_ID_0

*output Tab2 regression table 
cd "output"
esttab sub_diff_IP_ID_0 ///
	   using MS16-292Tab2_regression.tex, ///
	   mlabel("Total") ///
	   label wrap cells(b(star fmt(%9.1f) vacant("-") label(Coef.)) ///
						se(par fmt(%9.1f) label(SE))) ///
	   varwidth(10) starlevels(* .10 ** .05 *** .01) stats(N r2_a, fmt(0 2) ///
	   labels("Obs." "Adj. \begin{math}R^2\end{math}")) nonum replace
